Chronophore
===========

.. image:: https://img.shields.io/pypi/v/chronophore.svg?maxAge=2592000
    :target: https://pypi.python.org/pypi/chronophore

.. figure:: docs/screenshot_program.png
   :alt: Tk Interface

   Tk Interface

Chronophore is a simple time-tracking program. It keeps track of users'
hours as they sign in and out. Data is stored in a human-readable json
file.

.. figure:: docs/screenshot_data.png
   :alt: Example Json Data

   Example Json Data

This project was started to help keep track of students signing in and
out at a tutoring program in a community college, but should be
adaptable to other use cases.
